==> haskell-gi-cairo-render-0.1.2-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-cairo-render.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-cairo-render
version:                0.1.2
visibility:             public
id:                     gi-cairo-render-0.1.2-4gcg4XDIbDNJPFSKzkfBjY
key:                    gi-cairo-render-0.1.2-4gcg4XDIbDNJPFSKzkfBjY
license:                BSD-3-Clause
copyright:
    (c) 2018 Kilian Kilger, (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004

maintainer:             Kilian Kilger (kkilger@gmail.com)
author:                 Axel Simon, Duncan Coutts
stability:              experimental
homepage:               https://github.com/cohomology/gi-cairo-render
synopsis:               GI friendly Binding to the Cairo library.
description:
    Cairo is a library to render high quality vector graphics. There
    exist various backends that allows rendering to Gtk windows, PDF,
    PS, PNG and SVG documents, amongst others.

category:               Graphics
abi:                    ca88415bafa56f2b0bd12492e23d95fa
exposed:                True
exposed-modules:
    GI.Cairo.Render GI.Cairo.Render.Internal GI.Cairo.Render.Matrix
    GI.Cairo.Render.Types

hidden-modules:
    GI.Cairo.Render.Internal.Drawing.Cairo
    GI.Cairo.Render.Internal.Drawing.Paths
    GI.Cairo.Render.Internal.Drawing.Patterns
    GI.Cairo.Render.Internal.Drawing.Text
    GI.Cairo.Render.Internal.Drawing.Transformations
    GI.Cairo.Render.Internal.Fonts.FontOptions
    GI.Cairo.Render.Internal.Surfaces.Image
    GI.Cairo.Render.Internal.Surfaces.PNG
    GI.Cairo.Render.Internal.Surfaces.Surface
    GI.Cairo.Render.Internal.Utilities
    GI.Cairo.Render.Internal.Surfaces.PDF
    GI.Cairo.Render.Internal.Surfaces.PS
    GI.Cairo.Render.Internal.Surfaces.SVG
    GI.Cairo.Render.Internal.Region

import-dirs:            /usr/lib/ghc-9.4.8/site-local/gi-cairo-render-0.1.2
library-dirs:           /usr/lib/ghc-9.4.8/site-local/gi-cairo-render-0.1.2
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/gi-cairo-render-0.1.2
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-gi-cairo-render
hs-libraries:           HSgi-cairo-render-0.1.2-4gcg4XDIbDNJPFSKzkfBjY
extra-libraries:        cairo-gobject gobject-2.0 cairo glib-2.0 png16 z
extra-libraries-static:
    cairo-gobject m dl gobject-2.0 ffi cairo m dl fontconfig m expat m
    freetype bz2 harfbuzz m glib-2.0 m sysprof-capture-4 pcre2-8
    graphite2 brotlidec brotlicommon Xext Xrender X11 pthread
    xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m png16 m m z

include-dirs:
    /usr/include/cairo /usr/include/freetype2 /usr/include/harfbuzz
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6 /usr/include/pixman-1 /usr/include/libpng16

depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    haskell-gi-base-0.26.6-8Q7bG4vZp6hk1q5uA8ktg mtl-2.2.2 text-2.0.2
    utf8-string-1.0.2-4puy9i6JhHg6bynwSjfiUA

haddock-interfaces:
    /usr/share/doc/haskell-gi-cairo-render/html/gi-cairo-render.haddock

haddock-html:           /usr/share/doc/haskell-gi-cairo-render/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gi-cairo-render-0.1.2-88-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-cairo-render.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-cairo-render
version:                0.1.2
visibility:             public
id:                     gi-cairo-render-0.1.2-BVNAyu205L35vltOlxwxUz
key:                    gi-cairo-render-0.1.2-BVNAyu205L35vltOlxwxUz
license:                BSD-3-Clause
copyright:
    (c) 2018 Kilian Kilger, (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004

maintainer:             Kilian Kilger (kkilger@gmail.com)
author:                 Axel Simon, Duncan Coutts
stability:              experimental
homepage:               https://github.com/cohomology/gi-cairo-render
synopsis:               GI friendly Binding to the Cairo library.
description:
    Cairo is a library to render high quality vector graphics. There
    exist various backends that allows rendering to Gtk windows, PDF,
    PS, PNG and SVG documents, amongst others.

category:               Graphics
abi:                    7b9f0764c49b09024b690973bff3908d
exposed:                True
exposed-modules:
    GI.Cairo.Render GI.Cairo.Render.Internal GI.Cairo.Render.Matrix
    GI.Cairo.Render.Types

hidden-modules:
    GI.Cairo.Render.Internal.Drawing.Cairo
    GI.Cairo.Render.Internal.Drawing.Paths
    GI.Cairo.Render.Internal.Drawing.Patterns
    GI.Cairo.Render.Internal.Drawing.Text
    GI.Cairo.Render.Internal.Drawing.Transformations
    GI.Cairo.Render.Internal.Fonts.FontOptions
    GI.Cairo.Render.Internal.Surfaces.Image
    GI.Cairo.Render.Internal.Surfaces.PNG
    GI.Cairo.Render.Internal.Surfaces.Surface
    GI.Cairo.Render.Internal.Utilities
    GI.Cairo.Render.Internal.Surfaces.PDF
    GI.Cairo.Render.Internal.Surfaces.PS
    GI.Cairo.Render.Internal.Surfaces.SVG
    GI.Cairo.Render.Internal.Region

import-dirs:            /usr/lib/ghc-9.4.8/site-local/gi-cairo-render-0.1.2
library-dirs:           /usr/lib/ghc-9.4.8/site-local/gi-cairo-render-0.1.2
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/gi-cairo-render-0.1.2
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-gi-cairo-render
hs-libraries:           HSgi-cairo-render-0.1.2-BVNAyu205L35vltOlxwxUz
extra-libraries:        cairo-gobject gobject-2.0 cairo glib-2.0 png16 z
extra-libraries-static:
    cairo-gobject m dl gobject-2.0 ffi cairo m dl fontconfig m expat m
    freetype bz2 harfbuzz m glib-2.0 m sysprof-capture-4 pcre2-8
    graphite2 brotlidec brotlicommon Xext Xrender X11 pthread
    xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m png16 m m z

include-dirs:
    /usr/include/cairo /usr/include/freetype2 /usr/include/harfbuzz
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6 /usr/include/pixman-1 /usr/include/libpng16

depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    haskell-gi-base-0.26.6-8Q7bG4vZp6hk1q5uA8ktg mtl-2.2.2 text-2.0.2
    utf8-string-1.0.2-LQzUWC2hIN17FDKHsw4I2c

haddock-interfaces:
    /usr/share/doc/haskell-gi-cairo-render/html/gi-cairo-render.haddock

haddock-html:           /usr/share/doc/haskell-gi-cairo-render/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
